package com.fs.delivery.service.impl;

import java.util.List;
import com.fs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.delivery.mapper.CtCloudClassMapper;
import com.fs.delivery.domain.CtCloudClass;
import com.fs.delivery.service.ICtCloudClassService;

/**
 * 空中课堂内容维护Service业务层处理
 * 
 * @author fs
 * @date 2026-02-13
 */
@Service
public class CtCloudClassServiceImpl implements ICtCloudClassService 
{
    @Autowired
    private CtCloudClassMapper ctCloudClassMapper;

    /**
     * 查询空中课堂内容维护
     * 
     * @param cloudClassId 空中课堂内容维护主键
     * @return 空中课堂内容维护
     */
    @Override
    public CtCloudClass selectCtCloudClassByCloudClassId(Long cloudClassId)
    {
        return ctCloudClassMapper.selectCtCloudClassByCloudClassId(cloudClassId);
    }

    /**
     * 查询空中课堂内容维护列表
     * 
     * @param ctCloudClass 空中课堂内容维护
     * @return 空中课堂内容维护
     */
    @Override
    public List<CtCloudClass> selectCtCloudClassList(CtCloudClass ctCloudClass)
    {
        return ctCloudClassMapper.selectCtCloudClassList(ctCloudClass);
    }

    /**
     * 新增空中课堂内容维护
     * 
     * @param ctCloudClass 空中课堂内容维护
     * @return 结果
     */
    @Override
    public int insertCtCloudClass(CtCloudClass ctCloudClass)
    {
        ctCloudClass.setCreateTime(DateUtils.getNowDate());
        return ctCloudClassMapper.insertCtCloudClass(ctCloudClass);
    }

    /**
     * 修改空中课堂内容维护
     * 
     * @param ctCloudClass 空中课堂内容维护
     * @return 结果
     */
    @Override
    public int updateCtCloudClass(CtCloudClass ctCloudClass)
    {
        return ctCloudClassMapper.updateCtCloudClass(ctCloudClass);
    }

    /**
     * 批量删除空中课堂内容维护
     * 
     * @param cloudClassIds 需要删除的空中课堂内容维护主键
     * @return 结果
     */
    @Override
    public int deleteCtCloudClassByCloudClassIds(Long[] cloudClassIds)
    {
        return ctCloudClassMapper.deleteCtCloudClassByCloudClassIds(cloudClassIds);
    }

    /**
     * 删除空中课堂内容维护信息
     * 
     * @param cloudClassId 空中课堂内容维护主键
     * @return 结果
     */
    @Override
    public int deleteCtCloudClassByCloudClassId(Long cloudClassId)
    {
        return ctCloudClassMapper.deleteCtCloudClassByCloudClassId(cloudClassId);
    }
}
